==> qtjambi-virtualkeyboard-jre8-6.2.1-sources.jar: io/qt/keyboard/QVirtualKeyboardDictionary.java <==
package io.qt.keyboard;


/**
 * <p>An application-defined dictionary for virtual keyboard input methods</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qvirtualkeyboarddictionary.html">QVirtualKeyboardDictionary</a></p>
 */
public final class QVirtualKeyboardDictionary extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QVirtualKeyboardDictionary.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qvirtualkeyboarddictionary.html#contents-prop">QVirtualKeyboardDictionary::contentsChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="contents")
    public final Signal0 contentsChanged = new Signal0();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvirtualkeyboarddictionary.html#contents-prop">QVirtualKeyboardDictionary::contents()const</a></p>
     */
    @io.qt.QtPropertyReader(name="contents")
    @io.qt.QtUninvokable
    public final io.qt.core.QStringList contents(){
        return contents_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QStringList contents_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvirtualkeyboarddictionary.html#name-prop">QVirtualKeyboardDictionary::name()const</a></p>
     */
    @io.qt.QtPropertyReader(name="name")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvirtualkeyboarddictionary.html#contents-prop">QVirtualKeyboardDictionary::setContents(QStringList)</a></p>
     */
    @io.qt.QtPropertyWriter(name="contents")
    @io.qt.QtUninvokable
    public final void setContents(java.util.Collection<java.lang.String> contents){
        setContents_native_cref_QStringList(QtJambi_LibraryUtilities.internal.nativeId(this), contents);
    }
    
    @io.qt.QtUninvokable
    private native void setContents_native_cref_QStringList(long __this__nativeId, java.util.Collection<java.lang.String> contents);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QVirtualKeyboardDictionary(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-virtualkeyboard-jre8-6.3.0-sources.jar: io/qt/keyboard/QVirtualKeyboardDictionary.java <==
package io.qt.keyboard;


/**
 * <p>An application-defined dictionary for virtual keyboard input methods</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qvirtualkeyboarddictionary.html">QVirtualKeyboardDictionary</a></p>
 */
public final class QVirtualKeyboardDictionary extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QVirtualKeyboardDictionary.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qvirtualkeyboarddictionary.html#contents-prop">QVirtualKeyboardDictionary::contentsChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="contents")
    public final Signal0 contentsChanged = new Signal0();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvirtualkeyboarddictionary.html#contents-prop">QVirtualKeyboardDictionary::contents()const</a></p>
     */
    @io.qt.QtPropertyReader(name="contents")
    @io.qt.QtUninvokable
    public final io.qt.core.QStringList contents(){
        return contents_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QStringList contents_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvirtualkeyboarddictionary.html#name-prop">QVirtualKeyboardDictionary::name()const</a></p>
     */
    @io.qt.QtPropertyReader(name="name")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvirtualkeyboarddictionary.html#contents-prop">QVirtualKeyboardDictionary::resetContents()</a></p>
     */
    @io.qt.QtPropertyResetter(name="contents")
    @io.qt.QtUninvokable
    public final void resetContents(){
        resetContents_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void resetContents_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvirtualkeyboarddictionary.html#contents-prop">QVirtualKeyboardDictionary::setContents(QStringList)</a></p>
     */
    @io.qt.QtPropertyWriter(name="contents")
    @io.qt.QtUninvokable
    public final void setContents(java.util.Collection<java.lang.String> contents){
        setContents_native_cref_QStringList(QtJambi_LibraryUtilities.internal.nativeId(this), contents);
    }
    
    @io.qt.QtUninvokable
    private native void setContents_native_cref_QStringList(long __this__nativeId, java.util.Collection<java.lang.String> contents);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QVirtualKeyboardDictionary(QPrivateConstructor p) { super(p); } 
    
}
